/*
 * File:		UART_Packet_DMA.c
 * Purpose:		Main process
 *
 */

#include "common.h"
#include "uart.h"

#define DMA0_DESTINATION  (uint32)BufferTest      /* define the source data array address */      
#define DMA0_SOURCE_ADDR  0x4006A007            /* the memory adress of UART0_D register */ 

/* array to be sended */ 
uint8     BufferTest[1024]={0};
uint8     dma0_done = 0; 
uint8     Frame_End_Flag=0;
/*****************************************
 ***                                   ***
 ***  DMA0 intialization for UART0 RX  ***
 ***                                   ***
 *****************************************/
void DMA0_init(void){
  
  /* Enable Clock gating for the DMA and DMA MUX */
  SIM_SCGC6 |= SIM_SCGC6_DMAMUX_MASK;
  SIM_SCGC7 |= SIM_SCGC7_DMA_MASK;
  
  /* Create pointer & variable for reading DMA_DSR register */
  volatile uint32_t* dma_dsr_bcr0_reg = &DMA_DSR_BCR0;
  uint32_t dma_dsr_bcr0_val = *dma_dsr_bcr0_reg;
  
  DMAMUX0_CHCFG0 = 0x00;   //Disable DMA MUX channel first
  
  /* Check for pending erors and/or the done bit */
  if (((dma_dsr_bcr0_val & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK) 
      | ((dma_dsr_bcr0_val & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK) 
      | ((dma_dsr_bcr0_val & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
      | ((dma_dsr_bcr0_val & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
    DMA_DSR_BCR0 |= DMA_DSR_BCR_DONE_MASK;     //Clear pending erors and/or the done bit
  
  DMA_SAR0 = DMA0_SOURCE_ADDR;    //Set source address to UART0_D REG
  DMA_DSR_BCR0 = DMA_DSR_BCR_BCR(sizeof(BufferTest));    //Set BCR to know how many bytes to transfer
  DMA_DCR0 &= ~(DMA_DCR_SSIZE_MASK | DMA_DCR_DSIZE_MASK);    //Clear source size and destination size fields

  /* Set DMA as follows: 
       Source size is 8-bit size 
       Destination size is 8-bit size 
       Cycle steal mode 
       External requests are enabled 
       source address increments 1 automatically 
  */
  DMA_DCR0 |= (DMA_DCR_SSIZE(1) 
             | DMA_DCR_DSIZE(1) 
             | DMA_DCR_CS_MASK  
             | DMA_DCR_ERQ_MASK 
             | DMA_DCR_EINT_MASK 
             | DMA_DCR_DINC_MASK);

  DMA_DAR0 = DMA0_DESTINATION;    //Set destination address as buffer's first byte address
  DMAMUX0_CHCFG0 = DMAMUX_CHCFG_SOURCE(2);    //Select UART0 RX as channel source
  DMAMUX0_CHCFG0 |= DMAMUX_CHCFG_ENBL_MASK;    //Enable the DMA MUX channel
  
  enable_irq(INT_DMA0-16);
}

extern int uart0_clk_khz;
void UART0_DMA_init(void)
{    
  uart0_init (UART0_BASE_PTR, uart0_clk_khz, TERMINAL_BAUD);
  
  UART0_C2 &= ~(UART0_C2_TE_MASK | UART0_C2_RE_MASK);   //Disable UART0 first
  
  UART0_C5 |= UART0_C5_RDMAE_MASK;      // Turn on DMA request for UART0 received event
  
  UART0_C1 |= UART0_C1_ILT_MASK;        // Idle count start from the stop bit of previous byte

  UART0_C2 |= UART0_C2_ILIE_MASK;       // enable the IDLE line interrupt
  
  UART0_C2 |= (UART0_C2_TE_MASK | UART0_C2_RE_MASK);   //Enable UART0
 
  enable_irq (INT_UART0-16);
}
/********************************************************************/
int main (void)
{
     
  DMA0_init();
  
  UART0_DMA_init();
  
  printf("\n\r\n\r*** Running the UART_Packet_DMA project ***\n\r");

  while(1)
  {       
          
  } 
  
}

/********************************************************************/
void DMA0_Isr(void)
{ 
   
  /* Create pointer & variable for reading DMA_DSR register */ 
  volatile uint32_t* dma_dsr_bcr0_reg = &DMA_DSR_BCR0; 
  uint32_t dma_dsr_bcr0_val = *dma_dsr_bcr0_reg; 
   
  if (((dma_dsr_bcr0_val & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK) 
      | ((dma_dsr_bcr0_val & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK) 
      | ((dma_dsr_bcr0_val & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK) 
        | ((dma_dsr_bcr0_val & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
  {            
    DMA_DSR_BCR0 |= DMA_DSR_BCR_DONE_MASK;                //Clear Done bit 
    DMA_DSR_BCR0 = DMA_DSR_BCR_BCR(sizeof(BufferTest));      //Reset BCR 
    dma0_done = 1; 
  }  
  
}

void UART0_Isr(void)
{
  if(UART0_S1&UART0_S1_IDLE_MASK)// if IDLE Line interrupt occured
  {
    UART0_S1 |= UART0_S1_IDLE_MASK;// write 1 to clear interrupt flag
    
    Frame_End_Flag = 1;
    
    /* Reset the DMA */
    DMA_DSR_BCR0 |= DMA_DSR_BCR_DONE_MASK;                //Clear Done bit 
    DMA_DSR_BCR0 = DMA_DSR_BCR_BCR(sizeof(BufferTest));   //Reset BCR
    DMA_DAR0 = DMA0_DESTINATION;
  }
}